/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.subscriber;

import com.google.common.base.Strings;
import com.google.gson.Gson;
import org.junit.Before;
import org.opengroup.osdu.register.model.Subscriber;
import org.opengroup.osdu.register.util.Config;
import org.opengroup.osdu.register.util.CreateApiTestTemplate;
import org.opengroup.osdu.register.util.RestDescriptor;
import com.sun.jersey.api.client.ClientResponse;
import org.junit.BeforeClass;

import static org.junit.Assert.*;

public abstract class CreateSubscriberApiTest extends CreateApiTestTemplate {

    public CreateSubscriberApiTest() {
        super(new DeleteSubscriberDescriptor(), new CreateSubscriberDescriptor());
    }

    @Override
    public void setup() throws Exception {
        deleteResource();
    }

    @Override
    protected String getId() {
        return Config.Instance().subscriptionId;
    }

    @Override
    protected boolean isDataInTenant() {
        return true;
    }

    @Override
    protected void validate20XResponse(ClientResponse response, RestDescriptor descriptor) {
        String url = Config.Instance().PushUrl + "api/register/v1/test/challenge/1";
        String body = response.getEntity(String.class);
        Subscriber subscriber = new Gson().fromJson(body, Subscriber.class);
        assertEquals("My test listener.", subscriber.description);
        assertTrue(subscriber.createdBy, subscriber.createdBy.endsWith("gserviceaccount.com"));
        assertEquals("My listener", subscriber.name);
        assertEquals("records-changed", subscriber.topic);
        assertFalse(Strings.isNullOrEmpty(subscriber.notificationId));
        assertEquals(url, subscriber.pushEndpoint);
    }
}
