/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.subscriber;

import org.opengroup.osdu.register.util.Config;
import org.opengroup.osdu.register.util.RestDescriptor;
import org.opengroup.osdu.register.util.TestPayloadReader;

public class CreateSubscriberDescriptor extends RestDescriptor {
    private final TestPayloadReader reader = new TestPayloadReader();

    @Override
    public String getPath() {
        return "api/register/v1/subscription";
    }

    @Override
    public String getHttpMethod() {
        return "POST";
    }

    @Override
    public String getValidBody() {
        String url = Config.Instance().PushUrl + "api/register/v1/test/challenge/1";
        String secret = Config.Instance().SUBSCRIBER_SECRET;
        return "{\n" +
                "\t\"id\": \"" + getArg() + "\",\n" +
                "\t\"name\": \"My listener\",\n" +
                "\t\"description\": \"My test listener.\",\n" +
                "\t\"pushEndpoint\":\"" + url + "\",\n" +
                "\t\"topic\":\"records-changed\",\n" +
                "\t\"secret\": {\n" +
                "\t\t\"secretType\" : \"HMAC\",\n" +
                "\t\"value\":\"" + secret + "\"\n" +
                "\t}\n" +
                "}";
    }
}
