/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.subscriber;

import com.google.gson.Gson;
import org.junit.Before;
import org.opengroup.osdu.register.model.Subscriber;
import org.opengroup.osdu.register.util.BaseTestTemplate;
import org.opengroup.osdu.register.util.Config;
import org.opengroup.osdu.register.util.RestDescriptor;
import com.sun.jersey.api.client.ClientResponse;
import org.junit.BeforeClass;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

public abstract class QuerySubscriberTest extends BaseTestTemplate {

    Subscriber createdSubscriber;
    DeleteSubscriberDescriptor deleteDescriptor = new DeleteSubscriberDescriptor();

    public QuerySubscriberTest() {
        super(new QuerySubscriberDescriptor());
    }

    @Override
    public void setup() throws Exception {
        deleteResource();
    }

    @Override
    protected boolean isDataInTenant() {
        return true;
    }

    @Override
    protected String getId() {
        return Config.Instance().subscriptionId;
    }

    @Override
    protected void deleteResource() throws Exception {
        deleteDescriptor.run(getId(), testUtils.getOpsAccessToken());
    }

    @Override
    protected void createResource() throws Exception {
        ClientResponse response = new CreateSubscriberDescriptor().run(getId(), testUtils.getOpsAccessToken());
        String body = response.getEntity(String.class);
        createdSubscriber = new Gson().fromJson(body, Subscriber.class);
        assertEquals(error(body), 201, response.getStatus());
    }

    @Override
    protected int expectedOkResponseCode() {
        return 200;
    }

    @Override
    public void should_return20XResponseCode_when_makingValidHttpsRequest() throws Exception {
        createResource();
        ClientResponse response = descriptor.run(createdSubscriber.notificationId, testUtils.getOpsAccessToken());
        assertEquals(error(""), expectedOkResponseCode(), response.getStatus());
        validate20XResponse(response, descriptor);

        response = descriptor.run("de-randomNotificationId", testUtils.getOpsAccessToken());
        assertEquals(error(""), expectedOkResponseCode(), response.getStatus());
        String body = response.getEntity(String.class);
        Subscriber[] dmsArr = new Gson().fromJson(body, Subscriber[].class);
        List<Subscriber> allDms = Arrays.asList(dmsArr);
        assertEquals(0, allDms.size());

        deleteResource();
    }

    @Override
    protected void validate20XResponse(ClientResponse response, RestDescriptor descriptor) {
        String body = response.getEntity(String.class);
        Subscriber[] SubscriberArr = new Gson().fromJson(body, Subscriber[].class);
        List<Subscriber> subscriberList = Arrays.asList(SubscriberArr);
        assertTrue(subscriberList.size() >= 1);

        List<Subscriber> subscribers = subscriberList.stream().filter(f -> f.id.equalsIgnoreCase(getId())).collect(Collectors.toList());
        assertEquals(1, subscribers.size());
        String url = Config.Instance().PushUrl + "api/register/v1/test/challenge/1";
        assertEquals(1, subscribers.size());
        assertEquals(url, subscribers.get(0).pushEndpoint);
    }
}
